[paketler-commits] r8709 - stable/pardus-1/system/base/openssl

paketler-uludag at uludag.org.tr paketler-uludag at uludag.org.tr
30 Haz 2006 Cum 02:18:34 EEST


Author: cartman
Date: Fri Jun 30 02:18:34 2006
New Revision: 8709

Modified:
   stable/pardus-1/system/base/openssl/actions.py
   stable/pardus-1/system/base/openssl/pspec.xml
Log:
fix conflict


Modified: stable/pardus-1/system/base/openssl/actions.py
=================================================================
--- stable/pardus-1/system/base/openssl/pspec.xml	(original)
+++ stable/pardus-1/system/base/openssl/pspec.xml	Fri Jun 30 02:18:34 2006
@@ -38,6 +38,13 @@
     </Package>
     
     <History>
+        <Update release="5">
+            <Date>2006-06-30</Date>
+            <Version>0.9.7i</Version>
+            <Comment>Remove conflicting manpage</Comment>
+            <Name>İsmail Dönmez</Name>
+            <Email>ismail at pardus.org.tr</Email>
+        </Update>
         <Update release="4">
             <Date>2005-11-17</Date>
             <Version>0.9.7i</Version>


Paketler-commits mesaj listesiyle ilgili daha fazla bilgi
--- stable/pardus-1/system/base/openssl/actions.py	(original)
+++ stable/pardus-1/system/base/openssl/actions.py	Fri Jun 30 02:18:34 2006
@@ -28,12 +28,15 @@
     pisitools.insinto("/etc/ssl/certs/", "certs/*.pem")
     shelltools.system("OPENSSL=%s/usr/bin/openssl /usr/bin/perl tools/c_rehash %s/etc/ssl/certs" % (get.installDIR(), get.installDIR()))
 
     # The man pages rand.3 and passwd.1 conflict with other packages
     # Rename them to ssl-* and also make a symlink from openssl-* to ssl-*
     pisitools.domove("/usr/share/man/man1/passwd.1", "/usr/share/man/man1/", "ssl-passwd.1")
     pisitools.dosym("ssl-passwd.1", "/usr/share/man/man1/openssl-passwd.1")
 
     pisitools.domove("/usr/share/man/man3/rand.3", "/usr/share/man/man3/", "ssl-rand.3")
     pisitools.dosym("ssl-rand.3", "/usr/share/man/man3/openssl-rand.3")
+
+    pisitools.domove("/usr/share/man/man3/err.3", "/usr/share/man/man3/", "ssl-err.3")
+    pisitools.dosym("ssl-err.3", "/usr/share/man/man3/openssl-err.3")
  
     shelltools.chmod("%s/usr/lib/pkgconfig" % get.installDIR())
@@ -28,12 +28,15 @@
     shelltools.system("OPENSSL=%s/usr/bin/openssl /usr/bin/perl tools/c_rehash %s/etc/ssl/certs" % (get.installDIR(), get.installDIR()))
 
-    # The man pages rand.3 and passwd.1 conflict with other packages
+    # The man pages rand.3, err.3 and passwd.1 conflict with other packages
     # Rename them to ssl-* and also make a symlink from openssl-* to ssl-*
     pisitools.domove("/usr/share/man/man1/passwd.1", "/usr/share/man/man1/", "ssl-passwd.1")

Modified: stable/pardus-1/system/base/openssl/pspec.xml
=================================================================